"""Micropub clients (editors)."""

from understory import web
from understory.web import tx

__all__ = ["send"]


def send(properties, endpoint=None, h="entry", token=None):
    """Send a Micropub request to a Micropub server."""
    # TODO FIXME what's in the session?
    if endpoint is None:
        endpoint = tx.user.session["micropub_endpoint"]
    response = web.post(
        endpoint,
        headers={"Authorization": f"Bearer {token}"},
        json={"type": [f"h-{h}"], "properties": properties},
    )
    print(response.status)
    print(response.text)
    return response.location, response.links



"""
A library for writing [Micropub][0] servers and clients.

> The Micropub protocol is used to create, update and delete posts on
> one's own domain using third-party clients. Web apps and native apps
> (e.g. iPhone, Android) can use Micropub to post and edit articles,
> short notes, comments, likes, photos, events or other kinds of posts
> on your own website.

[0]: https://micropub.spec.indieweb.org

"""

from . import client, server

__all__ = ["client", "server"]
